@@ -6,9 +6,7 @@ import subprocess
 from typing import List
 
 
-parser: argparse.ArgumentParser = argparse.ArgumentParser(
-    description="Launch 35 merlin workflow jobs"
-)
+parser: argparse.ArgumentParser = argparse.ArgumentParser(description="Launch 35 merlin workflow jobs")
 parser.add_argument("run_id", type=int, help="The ID of this run")
 parser.add_argument("output_path", type=str, help="the output path")
 parser.add_argument("spec_path", type=str, help="path to the spec to run")
